#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 postgrest
version:              10.1.0
visibility:           public
id:                   postgrest-10.1.0-B0RfiLNGVkPJ7ETke8i23o
key:                  postgrest-10.1.0-B0RfiLNGVkPJ7ETke8i23o
license:              MIT
maintainer:           Steve Chavez <stevechavezast@gmail.com>
author:               Joe Nelson, Adam Baker, Steve Chavez
homepage:             https://postgrest.org
synopsis:             REST API for any Postgres database
description:
    Reads the schema of a PostgreSQL database and creates RESTful routes
    for tables, views, and functions, supporting all HTTP methods that security
    permits.

category:             Executable, PostgreSQL, Network APIs
abi:                  a56d73475f8e917246f3a8911a0ee443
exposed:              True
exposed-modules:
    PostgREST.ApiRequest PostgREST.ApiRequest.Preferences
    PostgREST.ApiRequest.QueryParams PostgREST.ApiRequest.Types
    PostgREST.App PostgREST.AppState PostgREST.Auth PostgREST.CLI
    PostgREST.Config PostgREST.Config.Database PostgREST.Config.JSPath
    PostgREST.Config.PgVersion PostgREST.Config.Proxy PostgREST.Cors
    PostgREST.Error PostgREST.Logger PostgREST.MediaType PostgREST.Plan
    PostgREST.Plan.CallPlan PostgREST.Plan.MutatePlan
    PostgREST.Plan.ReadPlan PostgREST.Query
    PostgREST.Query.QueryBuilder PostgREST.Query.SqlFragment
    PostgREST.Query.Statements PostgREST.RangeQuery PostgREST.Response
    PostgREST.Response.GucHeader PostgREST.Response.OpenAPI
    PostgREST.SchemaCache PostgREST.SchemaCache.Identifiers
    PostgREST.SchemaCache.Proc PostgREST.SchemaCache.Relationship
    PostgREST.SchemaCache.Table PostgREST.Unix PostgREST.Version
    PostgREST.Workers

hidden-modules:       Paths_postgrest
import-dirs:          /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/postgrest
hs-libraries:         HSpostgrest-10.1.0-B0RfiLNGVkPJ7ETke8i23o
depends:
    HTTP-4000.4.1-CC69OBaiOoN2fJPAAL6jfW
    Ranged-sets-0.5.0-HqcSdNwMEmYKWivbm6Xspt
    aeson-2.2.1.0-B3EHpOrhFBKFg56QPA2Q3I
    auto-update-0.1.6-EsZw4sLNwxYB5xYuaLBiHk base-4.18.2.1
    base64-bytestring-1.2.1.0-6zbb0o9xH9hLkYSzTxgmy9
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-L8b71mleMbHJVaC8zF8N1a
    cassava-0.5.4.1-IPPktMEWoqWF0Ksie8GZn7
    configurator-pg-0.2.11-E6daMnkFtUJcG4Wn7b8ty containers-0.6.7
    contravariant-extras-0.3.5.4-Jp1EzHgD0E5KQ707vKnuxI
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5 directory-1.3.8.5
    either-5.0.3-L97RCqrWS38xl66yyS973
    gitrev-1.3.1-HjgHeGOzFY1JvYhlt8eDSs
    hasql-1.6.1.1-DtCXICLlPajFeIGtmTQIa9
    hasql-dynamic-statements-0.3.1.2-DO3FFHTgAIEGKSChfAP1DA
    hasql-notifications-0.2.0.5-Dj8q6dYhUVeJYyDmZSTK0I
    hasql-pool-0.8.0.2-1CudsUt6k5zCNC42B9vbE7
    hasql-transaction-1.0.1.2-BTNFL1Zb68r4Dl6KY3omb
    heredoc-0.2.0.0-6fzsisYvDUd6tBbd4jIzIt
    http-types-0.12.4-4tdX51H3YCXI63KUlr8q5w
    insert-ordered-containers-0.2.5.3-3Zu2fPzinrLEKAlrJY2bsw
    interpolatedstring-perl6-1.0.2-LjakmMKZZYo6ZNQ6MAJ0uK
    jose-0.10-7WeGUweSKkC2r3NPmBO9lx lens-5.3.4-AArhojR1bHQDPd0CW0dSET
    lens-aeson-1.2.3-CpvTsokJAKT4oaewHiEZul mtl-2.3.1
    network-3.1.4.0-57XjnahcYfrBnbtgCzAhJP
    network-uri-2.6.4.2-1K7fB5RWUkvJzcj2EjtnE4
    optparse-applicative-0.18.1.0-3oCCN3996F8HtRiEC4P5yD
    parsec-3.1.16.1 protolude-0.3.5-3PlwTsS9mT95qyD8xPHlCN
    regex-tdfa-1.3.2.5-6zmUIdhGbUZEJaVpWcqCOZ
    retry-0.9.3.1-DYXcfDrVsgV1h8rt2rgh5D
    scientific-0.3.8.1-38VvnYA00bD5k7zFFQre1V
    swagger2-2.8.10-B0wemSt6JXb7XwlMwKjzGZ text-2.0.2 time-1.12.2
    unix-2.8.4.0 unordered-containers-0.2.20.1-24qNbjJ9xXJll0vtFCYfq
    vault-0.3.1.6-47rji3TOqbsJTd63j1Dkb3
    vector-0.13.2.0-5hQDxYlIzjI43Z4IxwIpHc
    wai-3.2.4-4nidytGQQ7OHwip6f8eKmG
    wai-cors-0.2.7-6W1CDrF8Kn32pQuWkQtGbn
    wai-extra-3.1.18-J3jesLn1Ee0KLAAxmswovI
    wai-logger-2.5.0-C3rSYPjmB4l2AZxqXMajNP
    warp-3.4.0-5oZttfNAemVKC6brQFzsdI

haddock-interfaces:   /usr/share/doc/postgrest/html/postgrest.haddock
haddock-html:         /usr/share/doc/postgrest/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

